@@ -51,18 +51,24 @@ long AcbAPI_create(void);
 
 bool AcbAPI_initialize(long acbId, AcbAPI_PlayerType playerType, const char *appId, AcbAPI_Callback callback);
 
-int AcbAPI_setMediaVideoData(long acbId, const char *payload);
-
-int AcbAPI_setState(long acbId, AcbAPI_AppState appState, AcbAPI_PlayState playState, long *taskId);
-
 bool AcbAPI_setMediaId(long acbId, const char *connId);
 
 bool AcbAPI_setSinkType(long acbId, AcbAPI_SinkType sinkType);
 
+int AcbAPI_setMediaAudioData(long acbId, const char *payload, long *taskId);
+
+int AcbAPI_setMediaVideoData(long acbId, const char *payload, long *taskId);
+
+int AcbAPI_setState(long acbId, AcbAPI_AppState appState, AcbAPI_PlayState playState, long *taskId);
+
 int AcbAPI_setDisplayWindow(long acbId, long x, long y, long w, long h, bool fullScreen, long *taskId);
 
 int AcbAPI_setCustomDisplayWindow(long acbId, long in_x, long in_y, long in_w, long in_h, long out_x, long out_y, long out_w, long out_h, bool fullScreen, long *taskId);
 
+int AcbAPI_startMute(long acbId, bool audio, bool video, long *taskId);
+
+int AcbAPI_stopMute(long acbId, bool audio, bool video, long *taskId);
+
 int AcbAPI_finalize(long acbId);
 
 void AcbAPI_destroy(long acbId);
