@@ -21,9 +21,9 @@ namespace smp {
         bool isPlatformRealtek(const std::string& platform);
         bool isPlatformSupportSoftwareAudioDecoder(std::string platform);
 
-        void isSupportedAudio(std::string audio, int32_t version, int32_t channel);
-        void isSupportedVideo(std::string video, int32_t width, int32_t height, int32_t frameRate, int64_t bitRate);
-        void isSupportedVideo(std::string video, int32_t width, int32_t height, int32_t frameRate, int64_t bitRate, std::string decodeType);
+        bool isSupportedAudio(std::string audio, int32_t version, int32_t channel);
+        bool isSupportedVideo(std::string video, int32_t width, int32_t height, int32_t frameRate, int64_t bitRate);
+        bool isSupportedVideo(std::string video, int32_t width, int32_t height, int32_t frameRate, int64_t bitRate, std::string decodeType);
 
         bool getMaxVideoResolution(std::string video, int32_t* width, int32_t* height, int32_t* frameRate);
         bool getMaxVideoResolution(std::string video, int32_t* width, int32_t* height, int32_t* frameRate, std::string decodeType);
@@ -65,6 +65,7 @@ public:
     bool Stop();
     bool takeSnapshot(const char *message);
     bool Unload();
+    bool changeAudioCodec(const std::string& acodec, const std::string& optInfo);
 #ifdef __G_MAIN_H__
     void setExternalContext(GMainContext *);
     void unsetExternalContext();
@@ -114,4 +115,4 @@ enum PF_EVENT_T
     PF_EVENT_TYPE_STR_BUFFERLOW = 0x2e,
     PF_EVENT_TYPE_DROPPED_FRAME = 0x30,
     PF_EVENT_USER_DEFINED = 0x270,
-};
\ No newline at end of file
+};
